import React from 'react';
import { Row, Col, Radio, DatePicker } from 'antd';
import moment from 'moment';
import 'moment/locale/zh-cn';
import locale from 'antd/es/date-picker/locale/zh_CN';

const { RangePicker } = DatePicker;
const radioOptions = [
  { label: '本月', value: '1' },
  // { label: '本季', value: '2' },
  { label: '本年', value: '3' },
];

export const last30Days = [
  moment().subtract(30, 'days'),
  moment(),
];

export const yearRange = [
  moment().startOf('year'),
  moment(),
]
export const quarterRange = [
  moment().startOf('quarter'),
  moment(),
]
export const monthRange = [
  moment().startOf('quarter'),
  moment(),
]

export default (props) => {
  const [dateRange, setDateRange] = React.useState([]);
  const [radioValue, setRadioValue] = React.useState();

  const onChange = (val) => {
    console.log(val);
    if (typeof props.onChange === 'function') {
      props.onChange(getStrValue(val));
    }
  }

  const onPickerChange = val => {
    setDateRange(val);
    setRadioValue();
    onChange(val);
  }

  const onRadioChange = e => {
    const val = e.target.value;
    setRadioValue(val);
    let dateRange = [];
    switch (val) {
      case '1':
        dateRange = monthRange;
        break;
      case '2':
        dateRange = quarterRange;
        break;
      case '3':
        dateRange = yearRange;
        break;
      default:
        break;
    }
    
    setDateRange(dateRange);
    onChange(dateRange);
  }

  return (
    <Row style={{ width: '460px' }} gutter={8}>
      <Col span={14}>
        <RangePicker locale={locale} value={dateRange} onChange={onPickerChange} />
      </Col>
      <Col span={10}>
        <Radio.Group
          options={radioOptions}
          value={radioValue}
          onChange={onRadioChange}
          optionType="button"
          buttonStyle="solid"
        />
      </Col>
    </Row>
  )
}

export function getStrValue(range) {
  return [
    range[0].format('YYYY-MM-DD'),
    range[1].format('YYYY-MM-DD'),
  ];
}
