import React from 'react';
import * as echarts from 'echarts/core';
import icon from '@/assets/images/statistic/任务统计.png';
import Chart from '@/components/chart';
import { getTaskInfo } from '@/services/statis';
import StatisCard from './StatisCard';
import Filter, { last30Days, getStrValue } from './Filter';

const defaultValue = getStrValue(last30Days);
export default (props) => {

  const [dateRange, setDateRange] = React.useState(defaultValue);
  const [option, setOption] = React.useState({});
  // const option = getOption(["1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"], [0, 0, 0, 0, 0, 0, 8, 9, 10, 1, 1, 6])

  React.useEffect(() => {
    getTaskInfo({ startDate: dateRange[0], endDate: dateRange[1] }).then(res => {
      const keys = res.map(x => x.dt);
      const vals = res.map(x => x.cnt);

      const opt = getOption(keys, vals);

      setOption(res.length > 30 ? { ...opt, dataZoom: { height: 20, bottom: 6 } } : opt);
    });
  }, [dateRange]);

  return (
    <StatisCard
      title="任务统计"
      icon={icon}
      extra={<Filter onChange={setDateRange} />}
    >
      <Chart option={option} style={{ height: '300px' }} />
    </StatisCard>
  )
}

function getOption(xAxisData, seriesData) {
  var axisLabel = {
    fontSize: 14,
    color: 'rgba(255,255,255, .6)',
  };
  var lineStyle = {
    color: 'rgba(255,255,255, .16)',
    type: 'dashed'
  };

  return {
    tooltip : {
      trigger: 'axis',
      axisPointer : {
        type : 'shadow'
      }
    },
    xAxis: {
      type: 'category',
      axisLabel: { ...axisLabel, rotate: 45 },
      axisLine: {
        show: true,
        lineStyle: lineStyle
      },
      data: xAxisData
    },
    yAxis: {
      axisLabel: axisLabel,
      axisLine: {
        show: true,
        lineStyle: lineStyle
      },
      splitLine: {
        lineStyle: lineStyle
      },
      type: 'value'
    },
    // dataZoom: [
    //   {
    //     show: true,
    //   }
    // ],
    grid: {
      top: 20,
      left: 50,
      right: 20,
      bottom: 100,
    },
    series: [
      {
        data: seriesData,
        type: 'bar',
        barWidth: 16,
        itemStyle: {
          borderRadius: [16, 16, 0, 0],
          color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
            { offset: 0, color: '#1EAED1' },
            { offset: 1, color: '#6F39B9' }
          ])
        }
      }
    ]
  }
}
